==> script-security-1.34-sources.jar: org/jenkinsci/plugins/scriptsecurity/scripts/languages/GroovyShellLanguage.java <==
/*
 * The MIT License
 *
 * Copyright 2014 CloudBees, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package org.jenkinsci.plugins.scriptsecurity.scripts.languages;

import org.jenkinsci.plugins.scriptsecurity.scripts.Language;
import hudson.Extension;
import hudson.ExtensionList;

/**
 * Language for Groovy Template scripts generating Bourne Shell script.
 */
@Extension public final class GroovyShellLanguage extends Language {

    public static Language get() {
        return ExtensionList.lookup(Language.class).get(GroovyShellLanguage.class);
    }

    @Override public String getName() {
        return "groovy-sh";
    }

    @Override public String getDisplayName() {
        return "Groovy Template for Shell";
    }

}

==> script-security-1.77-sources.jar: org/jenkinsci/plugins/scriptsecurity/scripts/languages/GroovyShellLanguage.java <==
/*
 * The MIT License
 *
 * Copyright 2014 CloudBees, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package org.jenkinsci.plugins.scriptsecurity.scripts.languages;

import org.jenkinsci.plugins.scriptsecurity.scripts.Language;
import hudson.Extension;
import hudson.ExtensionList;

/**
 * Language for Groovy Template scripts generating Bourne Shell script.
 * <p>The protection here is about the Groovy scripting,
 * similar to {@link GroovyLanguage} or {@link GroovyXmlLanguage}.
 * Not to be confused with unprocessed strings controlled by {@link SystemCommandLanguage}.
 */
@Extension public final class GroovyShellLanguage extends Language {

    public static Language get() {
        return ExtensionList.lookup(Language.class).get(GroovyShellLanguage.class);
    }

    @Override public String getName() {
        return "groovy-sh";
    }

    @Override public String getDisplayName() {
        return "Groovy Template for Shell";
    }

}
